@@ -274,7 +274,7 @@ sub make {
         $o = __PACKAGE__->new( %$p );
         next unless defined $o;
 
-        if( $o->reason eq '' || $o->reason =~ Sisimai::Reason->retry() ) {
+        if( $o->reason eq '' || grep { $o->reason eq $_ } @{ Sisimai::Reason->retry } ) {
             # Decide the reason of email bounce
             if( Sisimai::Rhost->match( $o->rhost ) ) {
                 # Remote host dependent error
