@@ -14,12 +14,12 @@ my $RxMSP = {
 };
 
 my $RxSess = {
-    'mesgtoobig' => [
-        qr/Mail size limit exceeded/,
-    ],
+    'mesgtoobig' => qr{
+        Mail[ ]size[ ]limit[ ]exceeded
+    }x,
 };
 
-sub version     { '4.0.0' }
+sub version     { '4.0.1' }
 sub description { '1&1: http://www.1and1.de' }
 sub smtpagent   { 'DE::EinsUndEins' }
 
@@ -41,6 +41,7 @@ sub scan {
     my $rfc822next = { 'from' => 0, 'to' => 0, 'subject' => 0 };
     my $previousfn = '';    # (String) Previous field name
 
+    my $longfields = __PACKAGE__->LONGFIELDS;
     my $stripedtxt = [ split( "\n", $$mbody ) ];
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
 
@@ -59,9 +60,10 @@ sub scan {
                 # Get required headers only
                 my $lhs = $1;
                 my $rhs = $2;
+                my $whs = lc $lhs;
 
                 $previousfn = '';
-                next unless grep { lc( $lhs ) eq lc( $_ ) } @$rfc822head;
+                next unless grep { $whs eq lc( $_ ) } @$rfc822head;
 
                 $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
@@ -69,12 +71,12 @@ sub scan {
             } elsif( $e =~ m/\A[\s\t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ lc $previousfn };
-                $rfc822part .= $e."\n" if $previousfn =~ m/\A(?:From|To|Subject)\z/;
+                $rfc822part .= $e."\n" if grep { $previousfn eq $_ } @$longfields;
 
             } else {
                 # Check the end of headers in rfc822 part
-                next unless $previousfn =~ m/\A(?:From|To|Subject)\z/;
-                next unless $e =~ m/\A\z/;
+                next unless grep { $previousfn eq $_ } @$longfields;
+                next if length $e;
                 $rfc822next->{ lc $previousfn } = 1;
             }
 
@@ -142,12 +144,9 @@ sub scan {
 
         SESSION: for my $r ( keys %$RxSess ) {
             # Verify each regular expression of session errors
-            PATTERN: for my $rr ( @{ $RxSess->{ $r } } ) {
-                # Check each regular expression
-                next unless $e->{'diagnosis'} =~ $rr;
-                $e->{'reason'} = $r;
-                last(SESSION);
-            }
+            next unless $e->{'diagnosis'} =~ $RxSess->{ $r };
+            $e->{'reason'} = $r;
+            last;
         }
 
         $e->{'status'}  =  Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
