@@ -15,7 +15,7 @@ my $RxMSP = {
     },
 };
 
-sub version     { '4.0.6' }
+sub version     { '4.0.7' }
 sub description { 'Verizon Wireless: http://www.verizonwireless.com' }
 sub smtpagent   { 'US::Verizon' }
 
@@ -44,6 +44,7 @@ sub scan {
     my $rfc822next = {};    # (Ref->Hash) Check flag for the end of headers in rfc822 part
     my $previousfn = '';    # (String) Previous field name
 
+    my $longfields = __PACKAGE__->LONGFIELDS;
     my $stripedtxt = [ split( "\n", $$mbody ) ];
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $senderaddr = '';    # (String) Sender address in the message body
@@ -70,10 +71,10 @@ sub scan {
         };
 
         $RxErr = {
-            'userunknown' => [
+            'userunknown' => qr{
                 # The attempted recipient address does not exist.
-                qr/550 - Requested action not taken: no such user here/,
-            ],
+                550[ ][-][ ]Requested[ ]action[ ]not[ ]taken:[ ]no[ ]such[ ]user[ ]here
+            }x,
         };
 
         $rfc822next = { 'from' => 0, 'to' => 0, 'subject' => 0 };
@@ -88,9 +89,10 @@ sub scan {
                     # Get required headers only
                     my $lhs = $1;
                     my $rhs = $2;
+                    my $whs = lc $lhs;
 
                     $previousfn = '';
-                    next unless grep { lc( $lhs ) eq lc( $_ ) } @$rfc822head;
+                    next unless grep { $whs eq lc( $_ ) } @$rfc822head;
 
                     $previousfn  = $lhs;
                     $rfc822part .= $e."\n";
@@ -98,12 +100,12 @@ sub scan {
                 } elsif( $e =~ m/\A[\s\t]+/ ) {
                     # Continued line from the previous line
                     next if $rfc822next->{ lc $previousfn };
-                    $rfc822part .= $e."\n" if $previousfn =~ m/\A(?:From|To|Subject)\z/;
+                    $rfc822part .= $e."\n" if grep { $previousfn eq $_ } @$longfields;
 
                 } else {
                     # Check the end of headers in rfc822 part
-                    next unless $previousfn =~ m/\A(?:From|To|Subject)\z/;
-                    next unless $e =~ m/\A\z/;
+                    next unless grep { $previousfn eq $_ } @$longfields;
+                    next if length $e;
                     $rfc822next->{ lc $previousfn } = 1;
                 }
 
@@ -162,9 +164,9 @@ sub scan {
         };
 
         $RxErr = {
-            'userunknown' => [
-                qr/No valid recipients for this MM/
-            ],
+            'userunknown' => qr{
+                No[ ]valid[ ]recipients[ ]for[ ]this[ ]MM
+            }x,
         };
 
         $rfc822next = { 'from' => 0, 'to' => 0, 'subject' => 0 };
@@ -179,9 +181,10 @@ sub scan {
                     # Get required headers only
                     my $lhs = $1;
                     my $rhs = $2;
+                    my $whs = lc $lhs;
 
                     $previousfn = '';
-                    next unless grep { lc( $lhs ) eq lc( $_ ) } @$rfc822head;
+                    next unless grep { $whs eq lc( $_ ) } @$rfc822head;
 
                     $previousfn  = $lhs;
                     $rfc822part .= $e."\n";
@@ -189,12 +192,12 @@ sub scan {
                 } elsif( $e =~ m/\A[\s\t]+/ ) {
                     # Continued line from the previous line
                     next if $rfc822next->{ lc $previousfn };
-                    $rfc822part .= $e."\n" if $previousfn =~ m/\A(?:From|To|Subject)\z/;
+                    $rfc822part .= $e."\n" if grep { $previousfn eq $_ } @$longfields;
 
                 } else {
                     # Check the end of headers in rfc822 part
-                    next unless $previousfn =~ m/\A(?:From|To|Subject)\z/;
-                    next unless $e =~ m/\A\z/;
+                    next unless grep { $previousfn eq $_ } @$longfields;
+                    next if length $e;
                     $rfc822next->{ lc $previousfn } = 1;
                 }
 
@@ -270,12 +273,9 @@ sub scan {
 
         SESSION: for my $r ( keys %$RxErr ) {
             # Verify each regular expression of session errors
-            PATTERN: for my $rr ( @{ $RxErr->{ $r } } ) {
-                # Check each regular expression
-                next(PATTERN) unless $e->{'diagnosis'} =~ $rr;
-                $e->{'reason'} = $r;
-                last(SESSION);
-            }
+            next unless $e->{'diagnosis'} =~ $RxErr->{ $r };
+            $e->{'reason'} = $r;
+            last;
         }
 
         $e->{'status'} = Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
