@@ -9,21 +9,20 @@ my $RxMSP = {
     'begin'   => qr/\AThis message was created automatically by mail delivery/,
     'rfc822'  => qr/\AReceived:\s*from mail[.]zoho[.]com/,
     'endof'   => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
-    'subject' => [
-        qr/\AUndelivered Mail Returned to Sender\z/,
-        qr/\AMail Delivery Status Notification/,
-    ],
+    'subject' => qr{\A(?:
+         Undelivered[ ]Mail[ ]Returned[ ]to[ ]Sender
+        |Mail[ ]Delivery[ ]Status[ ]Notification
+        )
+    }x,
     'x-mailer'=> qr/\AZoho Mail\z/,
 };
 
 my $RxSess = {
-    'expired' => [
-        qr/Host not reachable/
-    ],
+    'expired' => qr/Host not reachable/
 };
 
 
-sub version     { '4.0.2' }
+sub version     { '4.0.4' }
 sub description { 'Zoho Mail: https://www.zoho.com' }
 sub smtpagent   { 'US::Zoho' }
 sub headerlist  { 
@@ -39,8 +38,8 @@ sub scan {
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
 
-    return undef unless $mhead->{'from'} =~ $RxMSP->{'from'};
-    return undef unless grep { $mhead->{'subject'} =~ $_ } @{ $RxMSP->{'subject'} };
+    return undef unless $mhead->{'from'}     =~ $RxMSP->{'from'};
+    return undef unless $mhead->{'subject'}  =~ $RxMSP->{'subject'};
     return undef unless $mhead->{'x-mailer'} =~ $RxMSP->{'x-mailer'};
 
     my $dscontents = [];    # (Ref->Array) SMTP session errors: message/delivery-status
@@ -50,6 +49,7 @@ sub scan {
     my $previousfn = '';    # (String) Previous field name
     my $qprintable = 0;
 
+    my $longfields = __PACKAGE__->LONGFIELDS;
     my $stripedtxt = [ split( "\n", $$mbody ) ];
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
 
@@ -68,9 +68,10 @@ sub scan {
                 # Get required headers only
                 my $lhs = $1;
                 my $rhs = $2;
+                my $whs = lc $lhs;
 
                 $previousfn = '';
-                next unless grep { lc( $lhs ) eq lc( $_ ) } @$rfc822head;
+                next unless grep { $whs eq lc( $_ ) } @$rfc822head;
 
                 $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
@@ -78,12 +79,12 @@ sub scan {
             } elsif( $e =~ m/\A[\s\t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ lc $previousfn };
-                $rfc822part .= $e."\n" if $previousfn =~ m/\A(?:From|To|Subject)\z/;
+                $rfc822part .= $e."\n" if grep { $previousfn eq $_ } @$longfields;
 
             } else {
                 # Check the end of headers in rfc822 part
-                next unless $previousfn =~ m/\A(?:From|To|Subject)\z/;
-                next unless $e =~ m/\A\z/;
+                next unless grep { $previousfn eq $_ } @$longfields;
+                next if length $e;
                 $rfc822next->{ lc $previousfn } = 1;
             }
 
@@ -167,12 +168,9 @@ sub scan {
 
         SESSION: for my $r ( keys %$RxSess ) {
             # Verify each regular expression of session errors
-            PATTERN: for my $rr ( @{ $RxSess->{ $r } } ) {
-                # Check each regular expression
-                next unless $e->{'diagnosis'} =~ $rr;
-                $e->{'reason'} = $r;
-                last(SESSION);
-            }
+            next unless $e->{'diagnosis'} =~ $RxSess->{ $r };
+            $e->{'reason'} = $r;
+            last;
         }
 
         $e->{'status'}  =  Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
