@@ -14,13 +14,14 @@ my $RxMTA = {
 };
 
 my $RxErr = {
-    'userunknown' => [
-        qr/User not listed in public Name [&] Address Book/,
-        qr/ディレクトリのリストにありません/,
-    ],
+    'userunknown' => qr{(?:
+         User[ ]not[ ]listed[ ]in[ ]public[ ]Name[ ][&][ ]Address[ ]Book
+        |ディレクトリのリストにありません
+        )
+    }x,
 };
 
-sub version     { '4.0.3' }
+sub version     { '4.0.4' }
 sub description { 'Lotus Notes' }
 sub smtpagent   { 'Notes' }
 
@@ -41,6 +42,7 @@ sub scan {
     my $rfc822next = { 'from' => 0, 'to' => 0, 'subject' => 0 };
     my $previousfn = '';    # (String) Previous field name
 
+    my $longfields = __PACKAGE__->LONGFIELDS;
     my $stripedtxt = [ split( "\n", $$mbody ) ];
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $characters = '';    # (String) Character set name of the bounce mail
@@ -69,9 +71,10 @@ sub scan {
                 # Get required headers only
                 my $lhs = $1;
                 my $rhs = $2;
+                my $whs = lc $lhs;
 
                 $previousfn = '';
-                next unless grep { lc( $lhs ) eq lc( $_ ) } @$rfc822head;
+                next unless grep { $whs eq lc( $_ ) } @$rfc822head;
 
                 $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
@@ -79,12 +82,12 @@ sub scan {
             } elsif( $e =~ m/\A[\s\t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ lc $previousfn };
-                $rfc822part .= $e."\n" if $previousfn =~ m/\A(?:From|To|Subject)\z/;
+                $rfc822part .= $e."\n" if grep { $previousfn eq $_ } @$longfields;
 
             } else {
                 # Check the end of headers in rfc822 part
-                next unless $previousfn =~ m/\A(?:From|To|Subject)\z/;
-                next unless $e =~ m/\A\z/;
+                next unless grep { $previousfn eq $_ } @$longfields;
+                next if length $e;
                 $rfc822next->{ lc $previousfn } = 1;
             }
 
@@ -164,8 +167,9 @@ sub scan {
 
         for my $r ( keys %$RxErr ) {
             # Check each regular expression of Notes error messages
-            next unless grep { $e->{'diagnosis'} =~ $_ } @{ $RxErr->{ $r } };
+            next unless $e->{'diagnosis'} =~ $RxErr->{ $r };
             $e->{'reason'} = $r;
+
             my $s = Sisimai::RFC3463->status( $r, 'p', 'i' );
             $e->{'status'} = $s if length $s;
             last;
