@@ -22,8 +22,10 @@ sub list {
             MSP/JP/KDDI.pm
             MSP/RU/MailRu.pm
             MSP/RU/Yandex.pm
+            MSP/UK/MessageLabs.pm
             MSP/US/AmazonSES.pm
             MSP/US/Aol.pm
+            MSP/US/Bigfoot.pm
             MSP/US/Facebook.pm
             MSP/US/Google.pm
             MSP/US/Outlook.pm
